@@ -393,8 +393,8 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
             elif isinstance(element, addressable.AddressableAttribute):
                 if topic not in self.topics:
                     self.addTopic(topic)
-        elif flags & addressable.AddressableLeaf.ObserverEvent.VALUE_CHANGED \
-                or flags & addressable.AddressableLeaf.ObserverEvent.UPDATED_FROM_SERVER:
+        elif (flags & addressable.AddressableLeaf.ObserverEvent.VALUE_CHANGED) \
+                or (self.republishOnUpdate and (flags & addressable.AddressableLeaf.ObserverEvent.UPDATED_FROM_SERVER)):
             if isinstance(element.value, (str, int, float)) or element.value is None:
                 convertedValue = element.value
             if isinstance(element.value, (list)):
@@ -513,7 +513,7 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
         del mqttc  # unused
         del obj  # unused
         if self.ignore > 0 and self.lastSubscribe is not None and (datetime.now() - self.lastSubscribe) < timedelta(seconds=self.ignore):
-            LOG.info('ignoring message from broker as it is withing --ignore-for delta')
+            LOG.info('ignoring message from broker as it is within --ignore-for delta')
         elif len(msg.payload) == 0:
             LOG.debug('ignoring empty message')
         elif msg.topic == f'{self.prefix}/mqtt/weconnectForceUpdate':
@@ -546,22 +546,27 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
             if msg.topic.startswith(self.prefix):
                 address = msg.topic[len(self.prefix):]
                 attribute = self.weConnect.getByAddressString(address)
+                oldValue = attribute.value
                 if isinstance(attribute, addressable.ChangeableAttribute):
                     try:
                         attribute.value = msg.payload.decode()
                         self.setError(code=WeConnectErrors.SUCCESS)
+                        LOG.debug('Successfully set value')
                     except ValueError as valueError:
                         errorMessage = f'Error setting value: {valueError}'
                         self.setError(code=WeConnectErrors.SET_FORMAT, message=errorMessage)
                         LOG.info(errorMessage)
+                        self.publish(topic=msg.topic, qos=1, retain=False, payload=oldValue)
                     except errors.SetterError as setterError:
                         errorMessage = f'Error setting value: {setterError}'
                         self.setError(code=WeConnectErrors.SET_ERROR, message=errorMessage)
                         LOG.info(errorMessage)
+                        self.publish(topic=msg.topic, qos=1, retain=False, payload=oldValue)
                 else:
                     errorMessage = f'Trying to change item that is not a changeable attribute {msg.topic}: {msg.payload}'
                     self.setError(code=WeConnectErrors.MESSAGE_NOT_UNDERSTOOD, message=errorMessage)
                     LOG.error(errorMessage)
+                    self.publish(topic=msg.topic, qos=1, retain=False, payload=oldValue)
             else:
                 errorMessage = f'I don\'t understand message {msg.topic}: {msg.payload}'
                 self.setError(code=WeConnectErrors.ATTRIBUTE_NOT_CHANGEABLE, message=errorMessage)
